// Generated by dts-bundle-generator v9.5.1

export declare enum SocketDisconnectCode {
	CLOSE_NORMAL = 1000,
	CLOSE_GOING_AWAY = 1001,
	CLOSE_PROTOCOL_ERROR = 1002,
	CLOSE_UNSUPPORTED = 1003,
	CLOSE_NO_STATUS = 1005,
	CLOSE_ABNORMAL = 1006,
	CLOSE_TOO_LARGE = 1009,
	CLOSE_EXTENSION_REQUIRED = 1010,
	CLOSE_INTERNAL_ERROR = 1011,
	CLOSE_SERVICE_RESTART = 1012,
	CLOSE_TRY_AGAIN_LATER = 1013,
	CLOSE_TLS_HANDSHAKE = 1015
}
export declare enum ManagedSocketErrorType {
	INVALID_MESSAGE_SHAPE = "Invalid message shape.",
	CATASTROPHIC_CLOSE = "Catastrophic close code",
	SOCKET_ERROR = "WebSocket error",
	CONNECTION_REJECTED = "Connection rejected"
}
export declare class ManagedSocketError extends Error {
	originalError: Error | ErrorEvent;
	type: ManagedSocketErrorType;
	constructor(message: string, originalError: Error | ErrorEvent, type?: ManagedSocketErrorType);
}
export type SocketDataHandler = (data: unknown) => void | Promise<void>;
export type SocketErrorHandler = (error: ManagedSocketError) => void;
export type SocketOpenHandler = () => void;
export type SocketCloseHandler = () => void;
export type SocketCatastrophicErrorHandler = (error: ManagedSocketError) => void;
export type ManagedSocketConnectionState = "connecting" | "open" | "closing" | "closed" | "reconnecting" | "terminated";
export declare class ManagedSocket {
	readonly url: string;
	state: ManagedSocketConnectionState;
	private ws;
	private onMessageHandler;
	private onErrorHandler;
	private onOpenHandler;
	private onCloseHandler;
	private onCatastrophicErrorHandler;
	private reconnectAttempts;
	private maxReconnectDelay;
	private heartbeatInterval;
	private messageQueue;
	private attemptReconnect;
	private debugMode;
	constructor(url: string);
	get connected(): boolean;
	get native(): WebSocket;
	set debug(value: boolean);
	debugMessage(...args: unknown[]): void;
	private sendQueuedMessages;
	private connect;
	private handleCatastrophicError;
	onMessage(handler: SocketDataHandler): void;
	onError(handler: SocketErrorHandler): void;
	onOpen(handler: SocketOpenHandler): void;
	onClose(handler: SocketCloseHandler): void;
	onCatastrophicError(handler: SocketCatastrophicErrorHandler): void;
	reconnect(): void;
	close(): void;
	private startHeartbeat;
	private stopHeartbeat;
	send<T>(data: T): void;
}
declare const serializedSocketMessageBrand: unique symbol;
/**
 * Represents a serialized socket message.
 * This type is a branded string, ensuring type safety for serialized socket messages.
 */
export type SerializedSocketMessage = string & {
	[serializedSocketMessageBrand]: true;
};
/**
 * Represents a heartbeat message sent over a socket connection.
 * This message is used to indicate that the connection is still alive.
 */
export interface SocketHeartbeatMessage {
	type: "heartbeat";
	data: string;
}
/**
 * Represents a message with data to be handled by the application
 */
export interface SocketDataMessage {
	type: "message";
	data: unknown;
}
/**
 * Any socket message that can be sent or received.
 */
export type SocketMessage = SocketHeartbeatMessage | SocketDataMessage;
declare function createDataMessage(data: unknown): SocketDataMessage;
declare function createHeartbeatMessage(): SocketHeartbeatMessage;
declare function serialize(message: SocketMessage): SerializedSocketMessage;
declare function deserialize(data: string): SocketMessage;
declare function prepare<T>(data: T): SerializedSocketMessage;
declare function isCatastrophicCloseCode(code: number): boolean;
export declare const SocketSpeak: {
	createDataMessage: typeof createDataMessage;
	createHeartbeatMessage: typeof createHeartbeatMessage;
	serialize: typeof serialize;
	deserialize: typeof deserialize;
	isCatastrophicCloseCode: typeof isCatastrophicCloseCode;
	prepare: typeof prepare;
};

export {};
